# Table of Contents

- [sap-discovery-cloud-alm](<./sap-discovery-cloud-alm.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Cloud ALM Integration for SAP Discovery](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery.md>)
  - [Overview](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery/Overview.md>)
  - [Benefits](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery/Benefits.md>)
  - [Scope](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery/Scope.md>)
  - [Limitations](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery/Limitations.md>)
  - [Detailed Guides](<./SAP-Cloud-ALM-Integration-for-SAP-Discovery/Detailed-Guides.md>)
